translate.tools.pydiff.FileDiffer

Package translate :: Package tools :: Module pydiff :: Class FileDiffer |
[hide private]
[frames] | no frames]

# Class FileDiffer

source code

generates diffs between files

Instance Methods | [hide private]
__init__(self, fromfile, tofile, options) constructs a comparison between the two files using the given options | source code
writediff(self, outfile) writes the actual diff to the given file | source code
get_from_lines(self, group) returns the lines referred to by group, from the fromfile | source code
get_to_lines(self, group) returns the lines referred to by group, from the tofile | source code
unified_diff(self, group) takes the group of opcodes and generates a unified diff line by line | source code